print "

    foo
        a
        b
        c
    bar

    foo
        1
        2
        3
    bar

    foo
        0
        00
        000
    bar

    foo
        .
        ..
        ...
        ....
    bar


";
